# Job Bee Python Library

A Python library for interacting with the Job Bee system.

## Installation

```bash
pip install jobbee
```

## Getting started

How to access the Job Bee service with this library.

```python
from jobbee import JobBee

j = JobBee()
```
